// java wrapper for vtkLabelSizeCalculator object
//

package vtk;
import vtk.*;

public class vtkLabelSizeCalculator extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFontProperty_2(vtkTextProperty id0,int id1);
  public void SetFontProperty(vtkTextProperty id0,int id1)
    { SetFontProperty_2(id0,id1); }

  private native long GetFontProperty_3(int id0);
  public vtkTextProperty GetFontProperty(int id0) {
    long temp = GetFontProperty_3(id0);

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelSizeArrayName_4(String id0);
  public void SetLabelSizeArrayName(String id0)
    { SetLabelSizeArrayName_4(id0); }

  private native String GetLabelSizeArrayName_5();
  public String GetLabelSizeArrayName()
    { return GetLabelSizeArrayName_5(); }

  private native void SetDPI_6(int id0);
  public void SetDPI(int id0)
    { SetDPI_6(id0); }

  private native int GetDPI_7();
  public int GetDPI()
    { return GetDPI_7(); }

  public vtkLabelSizeCalculator() { super(); }

  public vtkLabelSizeCalculator(long id) { super(id); }
  public native long   VTKInit();

}
